@@ -43,6 +43,7 @@
 #include <telepathy-glib/svc-generic.h>
 #include <telepathy-glib/util.h>
 
+#include "channel-utils.h"
 #include "mcd-channel-priv.h"
 #include "mcd-dbusprop.h"
 #include "mcd-misc.h"
@@ -571,7 +572,7 @@ get_channels (TpSvcDBusProperties *iface, const gchar *name, GValue *value)
 
     g_value_init (value, TP_ARRAY_TYPE_CHANNEL_DETAILS_LIST);
     g_value_take_boxed (value,
-        _mcd_channel_details_build_from_list (self->priv->channels));
+        _mcd_tp_channel_details_build_from_list (self->priv->channels));
 }
 
 static void
@@ -623,7 +624,8 @@ mcd_dispatch_operation_set_channel_handled_by (McdDispatchOperation *self,
     _mcd_channel_set_status (channel, MCD_CHANNEL_STATUS_DISPATCHED);
 
     _mcd_handler_map_set_channel_handled (self->priv->handler_map,
-                                          tp_channel, unique_name);
+        tp_channel, unique_name,
+        _mcd_dispatch_operation_get_account_path (self));
 }
 
 static void
@@ -661,7 +663,7 @@ _mcd_dispatch_operation_finish (McdDispatchOperation *operation,
     }
 
     va_start (ap, format);
-    priv->result = g_error_new_valist (domain, code, format, ap);
+    priv->result = _mcd_g_error_new_valist (domain, code, format, ap);
     va_end (ap);
     DEBUG ("Result: %s", priv->result->message);
 
@@ -749,7 +751,6 @@ dispatch_operation_handle_with (TpSvcChannelDispatchOperation *cdo,
 {
     GError *error = NULL;
     McdDispatchOperation *self = MCD_DISPATCH_OPERATION (cdo);
-    GTimeVal now = { 0, 0 };
 
     DEBUG ("%s/%p", self->priv->unique_name, self);
 
@@ -760,8 +761,8 @@ dispatch_operation_handle_with (TpSvcChannelDispatchOperation *cdo,
         return;
     }
 
-    g_get_current_time (&now);
-    self->priv->handle_with_time = now.tv_sec;
+    /* 0 is a special case for 'no user action' */
+    self->priv->handle_with_time = 0;
 
     g_queue_push_tail (self->priv->approvals,
                        approval_new_handle_with (handler_name, context));
@@ -777,9 +778,13 @@ dispatch_operation_claim (TpSvcChannelDispatchOperation *cdo,
 
     if (self->priv->result != NULL)
     {
-        DEBUG ("Giving error to %s: %s", dbus_g_method_get_sender (context),
-               self->priv->result->message);
-        dbus_g_method_return_error (context, self->priv->result);
+        gchar *sender = dbus_g_method_get_sender (context);
+
+        DEBUG ("Giving error to %s: %s", sender, priv->result->message);
+        dbus_g_method_return_error (context, priv->result);
+
+        g_free (sender);
+
         return;
     }
 
@@ -1565,7 +1570,7 @@ _mcd_dispatch_operation_set_handler_failed (McdDispatchOperation *self,
         if (approval->type == APPROVAL_TYPE_HANDLE_WITH &&
             !tp_strdiff (approval->client_bus_name, bus_name))
         {
-            dbus_g_method_return_error (approval->context, error);
+            dbus_g_method_return_error (approval->context, (GError *) error);
             approval->context = NULL;
             approval_free (approval);
             g_queue_delete_link (self->priv->approvals, iter);
@@ -1834,7 +1839,7 @@ _mcd_dispatch_operation_run_observers (McdDispatchOperation *self)
 
         /* TODO: there's room for optimization here: reuse the channels_array,
          * if the observed list is the same */
-        channels_array = _mcd_channel_details_build_from_list (observed);
+        channels_array = _mcd_tp_channel_details_build_from_list (observed);
 
         satisfied_requests = collect_satisfied_requests (observed);
 
@@ -1858,7 +1863,7 @@ _mcd_dispatch_operation_run_observers (McdDispatchOperation *self)
          * McdChannel objects */
         g_ptr_array_free (satisfied_requests, TRUE);
 
-        _mcd_channel_details_free (channels_array);
+        _mcd_tp_channel_details_free (channels_array);
 
         g_list_free (observed);
     }
@@ -1946,7 +1951,7 @@ _mcd_dispatch_operation_run_approvers (McdDispatchOperation *self)
         dispatch_operation = _mcd_dispatch_operation_get_path (self);
         properties = _mcd_dispatch_operation_get_properties (self);
         channel_details =
-            _mcd_channel_details_build_from_list (self->priv->channels);
+            _mcd_tp_channel_details_build_from_list (self->priv->channels);
 
         DEBUG ("Calling AddDispatchOperation on approver %s for CDO %s @ %p",
                tp_proxy_get_bus_name (client), dispatch_operation, self);
