@@ -1,8 +1,9 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 8 -*- */
+/* vi: set et sw=4 ts=8 cino=t0,(0: */
+/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4; tab-width: 8 -*- */
 /*
  * This file is part of mission-control
  *
- * Copyright (C) 2007 Nokia Corporation. 
+ * Copyright (C) 2007-2009 Nokia Corporation.
  *
  * Contact: Naba Kumar  <naba.kumar@nokia.com>
  *
@@ -27,13 +28,6 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <libmissioncontrol/mc-account.h>
-#include <libmissioncontrol/mc-manager.h>
-
-#include "mcd-connection.h"
-#include "mcd-operation.h"
-#include "mcd-presence-frame.h"
-#include "mcd-dispatcher.h"
 
 G_BEGIN_DECLS
 
@@ -45,49 +39,64 @@ G_BEGIN_DECLS
 #define MCD_MANAGER_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), MCD_TYPE_MANAGER, McdManagerClass))
 
 typedef struct _McdManager McdManager;
+typedef struct _McdManagerPrivate McdManagerPrivate;
 typedef struct _McdManagerClass McdManagerClass;
 
+#include "mcd-account.h"
+#include "mcd-connection.h"
+#include "mcd-operation.h"
+#include "mcd-dispatcher.h"
+
 struct _McdManager
 {
     McdOperation parent;
+
+    McdManagerPrivate *priv;
 };
 
 struct _McdManagerClass
 {
     McdOperationClass parent_class;
-
-    /* signals */
-    void (*account_added_signal) (McdManager * manager, McAccount * account);
-    void (*account_removed_signal) (McdManager * manager,
-				    McAccount * account);
+    McdConnection *(*create_connection) (McdManager *manager,
+                                         McdAccount *account);
+    void (*_mc_reserved1) (void);
+    void (*_mc_reserved2) (void);
+    void (*_mc_reserved3) (void);
+    void (*_mc_reserved4) (void);
+    void (*_mc_reserved5) (void);
+    void (*_mc_reserved6) (void);
 };
 
 GType mcd_manager_get_type (void);
-McdManager *mcd_manager_new (McManager * mc_manager,
-			     McdPresenceFrame * pframe,
+McdManager *mcd_manager_new (const gchar *unique_name,
 			     McdDispatcher *dispatcher,
 			     TpDBusDaemon *dbus_daemon);
 
-gboolean mcd_manager_add_account (McdManager * manager, McAccount * account);
-gboolean mcd_manager_can_handle_account (McdManager * manager,
-					 McAccount *account);
-McAccount* mcd_manager_get_account_by_name (McdManager * manager,
-					       const gchar * account_name);
-gboolean mcd_manager_remove_account (McdManager * manager,
-				     McAccount * account);
-const GList *mcd_manager_get_accounts (McdManager * manager);
-McdConnection *mcd_manager_get_account_connection (McdManager * manager,
-						   McAccount * account);
-gboolean mcd_manager_request_channel (McdManager *manager,
-				      const struct mcd_channel_request *req,
-				      GError ** error);
+const gchar *mcd_manager_get_name (McdManager *manager);
+
+const TpConnectionManagerParam *
+mcd_manager_get_parameters (McdManager *manager, const gchar *protocol);
+
+const TpConnectionManagerParam *
+mcd_manager_get_protocol_param (McdManager *manager, const gchar *protocol,
+                                const gchar *param);
+
+McdConnection *mcd_manager_create_connection (McdManager *manager,
+					      McdAccount *account);
 
 gboolean mcd_manager_cancel_channel_request (McdManager *manager, guint operation_id,
 					     const gchar *requestor_client_pid, GError **error);
 
 McdConnection *mcd_manager_get_connection (McdManager *manager,
 					   const gchar *object_path);
-void mcd_manager_reconnect_account (McdManager *manager, McAccount *account);
+TpConnectionManager *mcd_manager_get_tp_proxy (McdManager *manager);
+McdDispatcher *mcd_manager_get_dispatcher (McdManager *manager);
+
+typedef void (*McdManagerReadyCb) (McdManager *manager, const GError *error,
+                                   gpointer user_data);
+void mcd_manager_call_when_ready (McdManager *manager,
+                                  McdManagerReadyCb callback,
+                                  gpointer user_data);
 
 G_END_DECLS
 #endif /* MCD_MANAGER_H */
