@@ -29,6 +29,7 @@
 #include <glib-object.h>
 
 #include <telepathy-glib/dbus.h>
+#include <telepathy-glib/defs.h>
 #include <libmcclient/mc-account-manager.h>
 #include <libmcclient/mc-account.h>
 #include <libmcclient/mc-profile.h>
@@ -175,27 +176,34 @@ set_param (GHashTable *parameters,
 	return FALSE;
 
     strv_type_key = g_strsplit (param_value, ":", 2);
-    if (strv_type_key[0] == NULL ||
-	strv_type_key[1] == NULL ||
-	strv_type_key[2] != NULL)
-	goto CLEANUP;
+
+    if (strv_type_key == NULL ||
+        strv_type_key[0] == NULL ||
+        strv_type_key[1] == NULL ||
+        strv_type_key[2] != NULL)
+        goto CLEANUP;
+
     type = strv_type_key[0];
     param = strv_type_key[1];
 
     if (clear)
     {
-	if (strcmp (type, "clear") == 0 || strcmp (type, "unset") == 0)
-	{
-	    g_ptr_array_add (clear, g_strdup (param));
-	    return TRUE;
-	}
+        if (strcmp (type, "clear") == 0 || strcmp (type, "unset") == 0)
+        {
+            g_ptr_array_add (clear, g_strdup (param));
+            ret = TRUE;
+            goto CLEANUP;
+        }
     }
 
     strv_param_value = g_strsplit (param, "=", 2);
-    if (strv_param_value[0] == NULL ||
-	strv_param_value[1] == NULL ||
-	strv_param_value[2] != NULL)
-	goto CLEANUP;
+
+    if (strv_param_value == NULL ||
+        strv_param_value[0] == NULL ||
+        strv_param_value[1] == NULL ||
+        strv_param_value[2] != NULL)
+        goto CLEANUP;
+
     key = strv_param_value[0];
     value = strv_param_value[1];
 
@@ -233,9 +241,7 @@ set_param (GHashTable *parameters,
 	g_free (gvalue);
 
 CLEANUP:
-    if (strv_param_value)
 	g_strfreev (strv_param_value);
-    if (strv_type_key)
 	g_strfreev (strv_type_key);
     return ret;
 }
@@ -1131,6 +1137,15 @@ main (int argc, char **argv)
     else {
 	command.common.account = prefix (command.common.account);
 	a = mc_account_new (daemon, command.common.account);
+
+	if (a == NULL)
+	{
+	    fprintf (stderr, "%s %s: '%s' is not a valid account name\n",
+		     app_name, command.common.name,
+		     strip (command.common.account));
+	    goto out;
+	}
+
 	mc_account_call_when_ready (a, account_ready, NULL);
     }
     g_object_unref (daemon);
@@ -1138,6 +1153,7 @@ main (int argc, char **argv)
     main_loop = g_main_loop_new (NULL, FALSE);
     g_main_loop_run (main_loop);
 
+out:
     if (am) g_object_unref (am);
     if (a) g_object_unref (a);
 
